#!/usr/bin/ruby
# encoding: utf-8

class VirusScreen

	def initialize(layers, fixed)
		@layers = layers
		@fixed = fixed
		@drive_vbox = Gtk::VBox.new
		@drive_widgets = Array.new
		lang = ENV['LANGUAGE'][0..1]
		lang = ENV['LANG'][0..1] if lang.nil?
		lang = "en" if lang.nil?
		@tl = MfsTranslator.new(lang, "VirusScreen.xml") 
		@start_label = @tl.get_translation("start_label") 
		create_first_layer 
		create_progress_layer
		create_settings_layer 
	end
	attr_reader :start_label 

	def create_first_layer
		bgimg = Gtk::Image.new("background.png")
		fx = Gtk::Fixed.new
		cancel = Gtk::Button.new(Gtk::Stock::CANCEL) 
		ok = Gtk::Button.new(Gtk::Stock::APPLY)
		set = Gtk::Button.new(Gtk::Stock::PREFERENCES) 
		fx.put(bgimg, 0, 0)
		# Label
		infolabel = Gtk::Label.new
		infolabel.wrap = true
		infolabel.width_request = 730
		infolabel.set_markup("virus_start") 
		fx.put(infolabel, 250, 100)
		
		# Scrollpane for drive selection
		scrl = Gtk::ScrolledWindow.new 
		scrl.set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC)
		scrl.width_request = 742
		scrl.height_request = 250
		fx.put(scrl, 250, 260)
		
		# Table containing drives
		drivetab = Gtk::Table.new(1000,2) 
		# drivecombo = Gtk::ComboBox.new
		scrl.add_with_viewport(@drive_vbox) 
		
		[ ok, cancel, set ].each { |w|
			w.width_request = 128
			w.height_request = 32 
		}
		cancel.signal_connect("clicked") { 
			@layers.each { |k,v| v.hide_all }
			@layers["start"].show_all 
		}
		ok.signal_connect("clicked") { 
			@layers.each { |k,v| v.hide_all }
			@layers["virus_running"].show_all 
		}
		set.signal_connect("clicked") { 
			@layers.each { |k,v| v.hide_all }
			@layers["virus_settings"].show_all 
		}
		fx.put(ok, OK_X, OK_Y)
		fx.put(cancel, CANCEL_X, CANCEL_Y)
		fx.put(set, SETTINGS_X, SETTINGS_Y)
		@fixed.put(fx, 0, 0)
		@layers["virus_start"] = fx
	end
	
	def create_progress_layer
		bgimg = Gtk::Image.new("background.png")
		fx = Gtk::Fixed.new
		cancel = Gtk::Button.new(Gtk::Stock::CANCEL) 
		ok = Gtk::Button.new(Gtk::Stock::OK)
		ok.sensitive = false
		fx.put(bgimg, 0, 0)
		# Label
		infolabel = Gtk::Label.new
		infolabel.wrap = true
		infolabel.width_request = 730
		infolabel.set_markup("virus_running")
		fx.put(infolabel, 250, 100)
		# Progress Bar
		pgbar = Gtk::ProgressBar.new
		pgbar.fraction = 0.3 
		pgbar.width_request = 730
		pgbar.height_request = 32
		fx.put(pgbar, 250, 240)
		cancel.signal_connect("clicked") { 
			@layers.each { |k,v| v.hide_all }
			@layers["start"].show_all 
		}
		[ ok, cancel ].each { |w|
			w.width_request = 128
			w.height_request = 32 
		}
		fx.put(ok, OK_X, OK_Y)
		fx.put(cancel, CANCEL_X, CANCEL_Y)
		@fixed.put(fx, 0, 0)
		@layers["virus_running"] = fx
	end
	
	def create_settings_layer
		bgimg = Gtk::Image.new("background.png")
		fx = Gtk::Fixed.new
		ok = Gtk::Button.new(Gtk::Stock::APPLY)
		fx.put(bgimg, 0, 0)
		# Label
		infolabel = Gtk::Label.new
		infolabel.wrap = true
		infolabel.width_request = 730
		infolabel.set_markup("virus_settings")
		fx.put(infolabel, 250, 100)
		fvbox = Gtk::VBox.new(false, 6)
		# frame for method
		frames = Array.new
		frames[0] = Gtk::Frame.new("virus_method")
		mvbox = Gtk::VBox.new(false, 6)
		meth_radio = Array.new
		meth_radio[0] = Gtk::RadioButton.new("all-files")
		meth_radio[1] = Gtk::RadioButton.new(meth_radio[0] , "avira-decides")
		meth_radio[2] = Gtk::RadioButton.new(meth_radio[0] , "bootsectors")
		meth_radio.each { |m|
			mvbox.pack_start(m, false, false, 0)
		}
		frames[0].add mvbox 
		# frame for categories
		frames[1] = Gtk::Frame.new("virus_categories")
		cattab = Gtk::Table.new(4, 2)
		cat_check = Array.new
		[ "dialer", "hidden", "privacy", "packer", "phishing", "backdoor", "fun", "games" ].each { |n|
			cat_check.push Gtk::CheckButton.new(n)
		}
		0.upto(cat_check.size-1) { |n|
			cattab.attach_defaults(cat_check[n], n%2, n%2+1, n/2, n/2+1)
		}
		frames[1].add cattab
		# frame for action
		frames[2] = Gtk::Frame.new("virus_action")
		avbox = Gtk::VBox.new(false, 6)
		act_radio = Array.new
		act_radio[0] = Gtk::RadioButton.new("protocol-only")
		act_radio[1] = Gtk::RadioButton.new(act_radio[0], "delete")
		act_radio[2] = Gtk::RadioButton.new(act_radio[0], "repair")
		act_radio.each { |m|
			avbox.pack_start(m, false, false, 0)
		}
		detvbox = Gtk::VBox.new(false, 6)
		det_radio = Array.new
		det_radio[0] = Gtk::RadioButton.new("rename")
		det_radio[1] = Gtk::RadioButton.new(det_radio[0], "delete")
		det_radio.each { |m|
			detvbox.pack_start(m, false, false, 0)
		}
		actdet_align = Gtk::Alignment.new(0.1, 0, 0, 0)
		actdet_align.add detvbox
		avbox.pack_start(actdet_align, false, false, 0)
		frames[2].add avbox 
		
		frames.each { |f|
			f.width_request = 740
			fvbox.pack_start_defaults(f)
		}
		fx.put(fvbox, 250, 140) 
		
		[ ok ].each { |w|
			w.width_request = 128
			w.height_request = 32 
		}
		ok.signal_connect("clicked") { 
			@layers.each { |k,v| v.hide_all }
			@layers["virus_start"].show_all 
		}
		fx.put(ok, OK_X, OK_Y)
		@fixed.put(fx, 0, 0)
		@layers["virus_settings"] = fx
		
	end
	
	def reread_drivelist
		drives = Array.new
		partitions = Array.new
		@drive_widgets.each { |w|
			@drive_vbox.remove(w) 
		}
		Dir.entries("/sys/block").each { |l|
			drives.push(MfsDiskDrive.new(l, false)) if l =~ /[a-z]$/ ||  l =~ /mmcblk[0-9]$/ ||  l =~ /mmcblk[0-9][0-9]$/
		}
		drives.each { |d|
			dlabel = "#{d.vendor} #{d.model}"
			if d.usb == true
				dlabel = dlabel + " (USB) "
			else
				dlabel = dlabel + " (SATA/eSATA/IDE) "
			end
			dlabel = dlabel + d.human_size
			l = Gtk::Label.new(dlabel) 
			@drive_vbox.pack_start_defaults(l)
			@drive_widgets.push(l)
			d.partitions.each  { |p|
				label = "#{p.device} #{p.human_size}"
				# label = @tl.get_translation("backup_medium") + " " + label if p.label.to_s == "USBDATA"
				pmnt = p.mount_point
				if ( p.fs =~ /vfat/ || p.fs =~ /ntfs/ || p.fs =~ /ext/ || p.fs =~ /btrfs/ ) # && pmnt.nil?
					label = label + " #{p.fs}"
					partitions.push p.device
					auxalign = Gtk::Alignment.new(0.02, 0, 0, 0)
					checkbox = Gtk::CheckButton.new(label)
					if pmnt.nil?
						checkbox.active = true if (p.fs =~ /vfat/ || p.fs =~ /ntfs/)
					else
						checkbox.sensitive = false
					end
					auxalign.add checkbox
					@drive_vbox.pack_start_defaults(auxalign) 
					@drive_widgets.push(auxalign)
				end
			}
		}
		
	end
	
	
end
